## 0.0.24

This new version introduces the ability to configure the port and address, providing more flexibility and control to the users.

### New Features

- Made port and address configurable, allowing users to set these parameters as per their requirements (0920e4) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
